package com.supermap.samplecode.mapping;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Toolkit;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;

import com.supermap.data.Workspace;
import com.supermap.ui.MapControl;

/**
 * <p>
 * Title:等级符号专题图
 * Title:graduated symbol map
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 *------------------------------Copyright Statement----------------------------
 *
 * This is the Sample Code of SuperMap iObjects JAVA
 * SuperMap Software Co., Ltd. All Rights Reserved. 
 *------------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：等级符号专题图的显示与清除，显示特定风格，设置流动显示
 * 2、示例数据：安装目录\SampleData\ThematicMaps\ThematicMaps.smwu
 * 3、关键类型/成员: 
 *      ThemeGraduatedSymbol.setFlowEnabled 方法
 *      ThemeGraduatedSymbol.setBaseValue 方法
 *      ThemeGraduatedSymbol.setExpression 方法
 *      ThemeGraduatedSymbol.setGraduatedMode 方法
 *      ThemeGraduatedSymbol.get/setPositiveStyle 方法
 *      GeoStyle.setLineColor 方法
 * 4、使用步骤：
 *  (1)窗体显示时，显示原始数据集图层
 *  (2)勾选显示专题图层勾选框，显示和清除专题图层
 * ------------------------------------------------------------------------------
 *-----------------------The description of SuperMap iObjects Java Sample Code --------------------------
 *
 *1.Sample Code Description:This sample demonstrates how to display and delete graduated symbol map. 
 *2.Sample Data:Installation directory\SampleData\ThematicMaps\ThematicMap.smwu
 *3.Key Classes/Methods: 
 *      ThemeGraduatedSymbol.setFlowEnabled method
 *      ThemeGraduatedSymbol.setBaseValue method
 *      ThemeGraduatedSymbol.setExpression method
 *      ThemeGraduatedSymbol.setGraduatedMode method
 *      ThemeGraduatedSymbol.get/setPositiveStyle method
 *      GeoStyle.setLineColor method
 *      
 *4.Procedures:
 *   (1)Display the layer of dataset when the Form starts.
 *   (2)If the CheckBox is selected the theme layer will be displayed, or the theme layer will be deleted.
 *---------------------------------------------------------------------------------------
 
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * Company: SuperMap Software Co., Ltd.
 * </p>
 * 
 */
public class MainFrame extends JFrame {

	private static final long serialVersionUID = 1L;

	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainFrame mainFrame = new MainFrame();
				mainFrame.setVisible(true);
				mainFrame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
			}
		});
	}

	public MainFrame() {
		try {
			initialize();
		} catch (Exception ex) {
			System.out.println(ex.getMessage());
		}
	}

	private void initialize() throws Exception {

		//设置窗体的标题和大小以及位置
		//Set the form's title, size and location
		this.setTitle(getText("this"));
		this.setExtendedState(JFrame.MAXIMIZED_BOTH);
		this.setSize(new Dimension(960, 800));
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		this.setLocation((screenSize.width - this.getSize().width) / 2,
				(screenSize.height - this.getSize().height) / 2);
		this.getContentPane().setLayout(new BorderLayout());
        
		m_panel = new JPanel();
		m_checkboxTheme = new JCheckBox();
		m_checkboxTheme.setSelected(true);
		m_checkboxTheme.setText(getText("m_checkboxTheme"));
		m_checkboxTheme.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				m_sampleRun.addThemeGraduatedDensity(m_checkboxTheme
						.isSelected());
			}
		});
		FlowLayout flowLayout = new FlowLayout();
		flowLayout.setAlignment(FlowLayout.LEFT);
		m_panel.setLayout(flowLayout);
		m_panel.add(m_checkboxTheme);
		this.getContentPane().add(m_panel, BorderLayout.NORTH);

		//设置MapControl
		// Set MapControl
		m_mapControl = new MapControl();
		this.getContentPane().add(m_mapControl, BorderLayout.CENTER);

		this.addWindowListener(new WindowAdapter() {
			// 在主窗体加载时，初始化SampleRun类型，来完成功能的展现
			// Initialize the SampleRun Type when the form loads
			public void windowOpened(WindowEvent e) {
				m_workspace = new Workspace();
				// 实例化m_sampleRun
				// Make an example of m_sampleRun
				m_sampleRun = new SampleRun(m_workspace, m_mapControl);
			}

			// 在窗体关闭时，需要释放相关的资源
			// Dispose the corresponding resources when the form closed
			public void windowClosing(WindowEvent e) {
				m_mapControl.dispose();
				m_workspace.dispose();
			}
		});

	}
	private String getText(String id)
	{
		String text = "";
		if (com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "this")
			{
				text = "等级符号专题图";
			}
			if(id == "m_checkboxTheme")
			{
				text = "显示专题图";
			}
		}
		else
		{
			if(id == "this")
			{
				text = "the Graduated Symbol map";
			}
			if(id == "m_checkboxTheme")
			{
				text = "Display the Graduated Symbol map";
			}
		}
		return text;
	}

	JPanel m_panel;

	JCheckBox m_checkboxTheme;

	Workspace m_workspace;

	MapControl m_mapControl;

	SampleRun m_sampleRun;
}

