package com.supermap.samplecode.mapping;

import java.awt.Color;

import com.supermap.data.DatasetVector;
import com.supermap.data.Datasets;
import com.supermap.data.Datasource;
import com.supermap.data.Datasources;
import com.supermap.data.GeoStyle;
import com.supermap.data.Size2D;
import com.supermap.data.Workspace;
import com.supermap.data.WorkspaceConnectionInfo;
import com.supermap.data.WorkspaceType;
import com.supermap.mapping.GraduatedMode;
import com.supermap.mapping.Layer;
import com.supermap.mapping.Layers;
import com.supermap.mapping.Map;
import com.supermap.mapping.ThemeDotDensity;
import com.supermap.mapping.ThemeGraduatedSymbol;
import com.supermap.ui.Action;
import com.supermap.ui.MapControl;

/**
 * <p>
 * Title:等级符号专题图
 * Title:graduated symbol map
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 *------------------------------Copyright Statement----------------------------
 *
 * This is the Sample Code of SuperMap iObjects JAVA
 * SuperMap Software Co., Ltd. All Rights Reserved. 
 *------------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：等级符号专题图的显示与清除，显示特定风格，设置流动显示
 * 2、示例数据：安装目录\SampleData\ThematicMaps\ThematicMaps.smwu
 * 3、关键类型/成员: 
 *      ThemeGraduatedSymbol.setFlowEnabled 方法
 *      ThemeGraduatedSymbol.setBaseValue 方法
 *      ThemeGraduatedSymbol.setExpression 方法
 *      ThemeGraduatedSymbol.setGraduatedMode 方法
 *      ThemeGraduatedSymbol.get/setPositiveStyle 方法
 *      GeoStyle.setLineColor 方法
 * 4、使用步骤：
 *  (1)窗体显示时，显示原始数据集图层
 *  (2)勾选显示专题图层勾选框，显示和清除专题图层
 * ------------------------------------------------------------------------------
 *-----------------------The description of SuperMap iObjects Java Sample Code --------------------------
 *
 *1.Sample Code Description:This sample demonstrates how to display and delete graduated symbol map. 
 *2.Sample Data:Installation directory\SampleData\ThematicMaps\ThematicMap.smwu
 *3.Key Classes/Methods: 
 *      ThemeGraduatedSymbol.setFlowEnabled method
 *      ThemeGraduatedSymbol.setBaseValue method
 *      ThemeGraduatedSymbol.setExpression method
 *      ThemeGraduatedSymbol.setGraduatedMode method
 *      ThemeGraduatedSymbol.get/setPositiveStyle method
 *      GeoStyle.setLineColor method
 *      
 *4.Procedures:
 *   (1)Display the layer of dataset when the Form starts.
 *   (2)If the CheckBox is selected the theme layer will be displayed, or the theme layer will be deleted.
 *---------------------------------------------------------------------------------------
 
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * Company: SuperMap Software Co., Ltd.
 * </p>
 * 
 */
public class SampleRun {

	private Workspace m_workspace;

	private MapControl m_mapControl;

	private Layer m_layerThemeGraduatedDensity;

	private DatasetVector m_dataset;

	public SampleRun(Workspace workspace, MapControl mapControl) {
		this.m_workspace = workspace;
		this.m_mapControl = mapControl;
		initialize();
	}

	/**
	 * 打开需要的工作空间文件及地图
	 * Open the workspace and the map
	 */
	private void initialize() {

		try {
			// 打开工作空间
			// Open the workspace and the map
			WorkspaceConnectionInfo workspaceConnectionInfo = new WorkspaceConnectionInfo();
			workspaceConnectionInfo.setType(WorkspaceType.SMWU);
			workspaceConnectionInfo
					.setServer("../../SampleData/ThematicMaps/Thematicmaps.smwu");
			m_workspace.open(workspaceConnectionInfo);
			m_dataset = (DatasetVector) m_workspace.getDatasources().get(0)
					.getDatasets().get("BaseMap_R");
			m_mapControl.getMap().setWorkspace(m_workspace);
			m_mapControl.getMap().open(getText("m_mapControl"));
			m_mapControl.getMap().refresh();

			// 调整mapControl的状态
			// Adjust the condition of mapControl
			m_mapControl.setAction(Action.PAN);

			// 显示等级符号专题图
			// Add the theme of graduated symbol
			addThemeGraduatedDensity(true);

		} catch (Exception ex) {
			System.out.println(ex.getMessage());
		}
	}

	public void addThemeGraduatedDensity(boolean value) {

		if (m_layerThemeGraduatedDensity == null) {
			try {
				ThemeGraduatedSymbol themeGraduatedDensity = new ThemeGraduatedSymbol();
				themeGraduatedDensity.setExpression("Urban");
				themeGraduatedDensity.setBaseValue(150.00000);
				themeGraduatedDensity
						.setGraduatedMode(GraduatedMode.SQUAREROOT);
				themeGraduatedDensity.setFlowEnabled(false);
				GeoStyle geoStyle = themeGraduatedDensity.getPositiveStyle();
				geoStyle.setLineColor(Color.PINK);
				themeGraduatedDensity.setPositiveStyle(geoStyle);

				// 将制作好的专题图添加到地图中显示
				// Add the graduated symbol map to the mapControl to display
				m_layerThemeGraduatedDensity = m_mapControl.getMap()
						.getLayers()
						.add(m_dataset, themeGraduatedDensity, true);
			} catch (Exception ex) {
				System.out.println(ex.getMessage());
			}

		}
		// 设置图层是否可显示，刷新地图，并设置图例面板
		// Set whether the layer visible, refresh the map and set the legend panel
		m_layerThemeGraduatedDensity.setVisible(value);
		m_mapControl.getMap().refresh();

	}
	
	private String getText(String id)
	{
		String text = "";
		if (com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "m_mapControl")
			{
				text = "京津地区地图";
			}
		}
		else
		{
			if(id == "m_mapControl")
			{
				text = "Beijing-Tianjin Area Division Map";
			}
		}
		return text;
	}

}

